@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2013-2023 darktable developers.
+    Copyright (C) 2013-2024 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -63,6 +63,12 @@ const char *name(dt_lib_module_t *self)
   return _("mask manager");
 }
 
+const char *description(dt_lib_module_t *self)
+{
+  return _("manipulate the drawn shapes used\n"
+           "for masks on the processing modules");
+}
+
 dt_view_type_flags_t views(dt_lib_module_t *self)
 {
   return DT_VIEW_DARKROOM;
@@ -169,7 +175,7 @@ static void _property_changed(GtkWidget *widget, dt_masks_property_t prop)
   {
     for(GList *fpts = form->points; fpts; fpts = g_list_next(fpts), pos++)
     {
-      dt_masks_point_group_t *fpt = (dt_masks_point_group_t *)fpts->data;
+      dt_masks_point_group_t *fpt = fpts->data;
       dt_masks_form_t *sel = dt_masks_get_from_id(darktable.develop, fpt->formid);
       if(!sel
          || (dev->mask_form_selected_id && dev->mask_form_selected_id != sel->formid))
@@ -272,7 +278,7 @@ static void _lib_masks_get_values(GtkTreeModel *model,
 
 static void _lib_masks_inactivate_icons(dt_lib_module_t *self)
 {
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
 
   // we set the add shape icons inactive
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lm->bt_circle), FALSE);
@@ -349,7 +355,7 @@ static void _tree_add_exist(GtkButton *button, dt_masks_form_t *grp)
 
 static void _tree_group(GtkButton *button, dt_lib_module_t *self)
 {
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
   // we create the new group
   dt_masks_form_t *grp = dt_masks_create(DT_MASKS_GROUP);
   snprintf(grp->name, sizeof(grp->name), _("group #%d"),
@@ -372,8 +378,7 @@ static void _tree_group(GtkButton *button, dt_lib_module_t *self)
 
       if(dt_is_valid_maskid(id))
       {
-        dt_masks_point_group_t *fpt =
-          (dt_masks_point_group_t *)malloc(sizeof(dt_masks_point_group_t));
+        dt_masks_point_group_t *fpt = malloc(sizeof(dt_masks_point_group_t));
         fpt->formid = id;
         fpt->parentid = grp->formid;
         fpt->opacity = 1.0f;
@@ -460,7 +465,7 @@ static void _tree_operation(GtkButton *button, gpointer user_data)
 {
   dt_masks_state_t change_state = GPOINTER_TO_INT(user_data);
   dt_lib_module_t *self = darktable.develop->proxy.masks.module;
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
 
   // now we go through all selected nodes
   GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(lm->treeview));
@@ -487,7 +492,7 @@ static void _tree_operation(GtkButton *button, gpointer user_data)
         // we search the entry to inverse
         for(const GList *pts = grp->points; pts; pts = g_list_next(pts))
         {
-          dt_masks_point_group_t *pt = (dt_masks_point_group_t *)pts->data;
+          dt_masks_point_group_t *pt = pts->data;
           if(pt->formid == id)
           {
             if(change_state == DT_MASKS_STATE_INVERSE
@@ -549,7 +554,7 @@ static void _swap_last_secondlast_item_visibility(dt_lib_masks_t *lm,
     // the new second last node is set SHOW state + UNION if no operator defined yet.
     for(const GList *pts = g_list_last(grp->points); pts; pts = g_list_previous(pts))
     {
-      dt_masks_point_group_t *pt = (dt_masks_point_group_t *)pts->data;
+      dt_masks_point_group_t *pt = pts->data;
       gboolean changed = FALSE;
       if(pt->formid == last_id)
       {
@@ -584,7 +589,7 @@ static gboolean _is_last_tree_item(GtkTreeModel *model, GtkTreeIter *iter)
 
 static void _tree_moveup(GtkButton *button, dt_lib_module_t *self)
 {
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
 
   dt_masks_clear_form_gui(darktable.develop);
 
@@ -629,7 +634,7 @@ static void _tree_moveup(GtkButton *button, dt_lib_module_t *self)
 
 static void _tree_movedown(GtkButton *button, dt_lib_module_t *self)
 {
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
 
   dt_masks_clear_form_gui(darktable.develop);
 
@@ -674,7 +679,7 @@ static void _tree_movedown(GtkButton *button, dt_lib_module_t *self)
 
 static void _tree_delete_shape(GtkButton *button, dt_lib_module_t *self)
 {
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
 
   dt_masks_clear_form_gui(darktable.develop);
 
@@ -731,7 +736,7 @@ static void _tree_delete_shape(GtkButton *button, dt_lib_module_t *self)
 
 static void _tree_duplicate_shape(GtkButton *button, dt_lib_module_t *self)
 {
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
 
   // we get the selected node
   GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(lm->treeview));
@@ -760,7 +765,7 @@ static void _tree_cell_edited(GtkCellRendererText *cell,
                               gchar *new_text,
                               dt_lib_module_t *self)
 {
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
   GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(lm->treeview));
   GtkTreeIter iter;
   if(!gtk_tree_model_get_iter_from_string(model, &iter, path_string)) return;
@@ -811,8 +816,7 @@ static void _tree_selection_change(GtkTreeSelection *selection, dt_lib_masks_t *
       dt_masks_form_t *form = dt_masks_get_from_id(darktable.develop, id);
       if(form)
       {
-        dt_masks_point_group_t *fpt =
-          (dt_masks_point_group_t *)malloc(sizeof(dt_masks_point_group_t));
+        dt_masks_point_group_t *fpt = malloc(sizeof(dt_masks_point_group_t));
         fpt->formid = id;
         fpt->parentid = grid;
         fpt->state = DT_MASKS_STATE_USE;
@@ -828,7 +832,7 @@ static void _tree_selection_change(GtkTreeSelection *selection, dt_lib_masks_t *
              && (module->flags() & IOP_FLAGS_SUPPORTS_BLENDING)
              && !(module->flags() & IOP_FLAGS_NO_MASKS))
           {
-            dt_iop_gui_blend_data_t *bd = (dt_iop_gui_blend_data_t *)module->blend_data;
+            dt_iop_gui_blend_data_t *bd = module->blend_data;
             bd->masks_shown = DT_MASKS_EDIT_FULL;
             gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bd->masks_edit), TRUE);
             gtk_widget_queue_draw(bd->masks_edit);
@@ -967,7 +971,7 @@ static int _tree_button_pressed(GtkWidget *treeview,
           {
             for(const GList *pts = grp2->points; pts; pts = g_list_next(pts))
             {
-              dt_masks_point_group_t *pt = (dt_masks_point_group_t *)pts->data;
+              dt_masks_point_group_t *pt = pts->data;
               if(pt->formid == id) selected_states |= pt->state;
             }
           }
@@ -1018,7 +1022,7 @@ static int _tree_button_pressed(GtkWidget *treeview,
           forms;
           forms = g_list_next(forms))
       {
-        dt_masks_form_t *form = (dt_masks_form_t *)forms->data;
+        dt_masks_form_t *form = forms->data;
         if((form->type & (DT_MASKS_CLONE|DT_MASKS_NON_CLONE)) || form->formid == grpid)
         {
           continue;
@@ -1032,13 +1036,13 @@ static int _tree_button_pressed(GtkWidget *treeview,
             modules;
             modules = g_list_next(modules))
         {
-          dt_iop_module_t *m = (dt_iop_module_t *)modules->data;
+          dt_iop_module_t *m = modules->data;
           dt_masks_form_t *grp = dt_masks_get_from_id(m->dev, m->blend_params->mask_id);
           if(grp && (grp->type & DT_MASKS_GROUP))
           {
             for(const GList *pts = grp->points; pts; pts = g_list_next(pts))
             {
-              dt_masks_point_group_t *pt = (dt_masks_point_group_t *)pts->data;
+              dt_masks_point_group_t *pt = pts->data;
               if(pt->formid == form->formid)
               {
                 if(m == module)
@@ -1249,7 +1253,7 @@ static void _is_form_used(const dt_mask_id_t formid,
         forms;
         forms = g_list_next(forms))
     {
-      dt_masks_form_t *form = (dt_masks_form_t *)forms->data;
+      dt_masks_form_t *form = forms->data;
       if(form->type & DT_MASKS_GROUP) _is_form_used(formid, form, text, text_length, nb);
     }
   }
@@ -1259,7 +1263,7 @@ static void _is_form_used(const dt_mask_id_t formid,
         points;
         points = g_list_next(points))
     {
-      dt_masks_point_group_t *point = (dt_masks_point_group_t *)points->data;
+      dt_masks_point_group_t *point = points->data;
       dt_masks_form_t *form = dt_masks_get_from_id(darktable.develop, point->formid);
       if(form)
       {
@@ -1372,7 +1376,7 @@ static void _lib_masks_list_recurs(GtkTreeStore *treestore,
     {
       for(const GList *iops = darktable.develop->iop; iops; iops = g_list_next(iops))
       {
-        dt_iop_module_t *iop = (dt_iop_module_t *)iops->data;
+        dt_iop_module_t *iop = iops->data;
         if((iop->flags() & IOP_FLAGS_SUPPORTS_BLENDING)
            && !(iop->flags() & IOP_FLAGS_NO_MASKS)
            && iop->blend_params->mask_id == form->formid)
@@ -1405,7 +1409,7 @@ static void _lib_masks_list_recurs(GtkTreeStore *treestore,
     // we add all nodes to the tree
     for(const GList *forms = form->points; forms; forms = g_list_next(forms))
     {
-      dt_masks_point_group_t *grpt = (dt_masks_point_group_t *)forms->data;
+      dt_masks_point_group_t *grpt = forms->data;
       dt_masks_form_t *f = dt_masks_get_from_id(darktable.develop, grpt->formid);
       if(f)
         _lib_masks_list_recurs(treestore, &child, f,
@@ -1448,7 +1452,7 @@ gboolean _find_mask_iter_by_values(GtkTreeModel *model,
 GList *_lib_masks_get_selected(dt_lib_module_t *self)
 {
   GList *res = NULL;
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
 
   GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(lm->treeview));
 
@@ -1481,7 +1485,7 @@ GList *_lib_masks_get_selected(dt_lib_module_t *self)
 void gui_update(dt_lib_module_t *self)
 {
   /* first destroy all buttons in list */
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
   if(!lm) return;
   if(darktable.gui->reset) return;
 
@@ -1513,7 +1517,7 @@ void gui_update(dt_lib_module_t *self)
       forms;
       forms = g_list_next(forms))
   {
-    dt_masks_form_t *form = (dt_masks_form_t *)forms->data;
+    dt_masks_form_t *form = forms->data;
     if(form->type & DT_MASKS_GROUP)
       _lib_masks_list_recurs(treestore, NULL, form, 0, NULL, 0, 1.0, lm);
   }
@@ -1523,7 +1527,7 @@ void gui_update(dt_lib_module_t *self)
       forms;
       forms = g_list_next(forms))
   {
-    dt_masks_form_t *form = (dt_masks_form_t *)forms->data;
+    dt_masks_form_t *form = forms->data;
     if(!(form->type & DT_MASKS_GROUP))
       _lib_masks_list_recurs(treestore, NULL, form, 0, NULL, 0, 1.0, lm);
   }
@@ -1537,7 +1541,7 @@ void gui_update(dt_lib_module_t *self)
     while(ids)
     {
       GtkTreeModel *model = GTK_TREE_MODEL(treestore);
-      dt_iop_module_t *mod = (dt_iop_module_t *)ids->data;
+      dt_iop_module_t *mod = ids->data;
       ids = g_list_next(ids);
       // const int gid = GPOINTER_TO_INT(ids->data); // not needed, skip it
       ids = g_list_next(ids);
@@ -1610,7 +1614,7 @@ static gboolean _update_foreach(GtkTreeModel *model,
   {
     for(const GList *pts = grp->points; pts; pts = g_list_next(pts))
     {
-      dt_masks_point_group_t *pt = (dt_masks_point_group_t *)pts->data;
+      dt_masks_point_group_t *pt = pts->data;
       if(pt->formid == id)
       {
         state = pt->state;
@@ -1626,7 +1630,7 @@ static gboolean _update_foreach(GtkTreeModel *model,
 
 static void _lib_masks_update_list(dt_lib_module_t *self)
 {
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
   // for each node , we refresh the string
   GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(lm->treeview));
   gtk_tree_model_foreach(model, _update_foreach, lm);
@@ -1656,7 +1660,7 @@ static gboolean _remove_foreach(GtkTreeModel *model,
 
 static void _lib_masks_remove_item(dt_lib_module_t *self, dt_mask_id_t formid, dt_mask_id_t parentid)
 {
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
   // for each node , we refresh the string
   GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(lm->treeview));
   GList *rl = NULL;
@@ -1726,7 +1730,7 @@ static void _lib_masks_selection_change(dt_lib_module_t *self,
                                         struct dt_iop_module_t *module,
                                         const dt_mask_id_t selectid)
 {
-  dt_lib_masks_t *lm = (dt_lib_masks_t *)self->data;
+  dt_lib_masks_t *lm = self->data;
   if(!lm->treeview) return;
 
   GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(lm->treeview));
@@ -1773,7 +1777,7 @@ static GdkPixbuf *_get_pixbuf_from_cairo(DTGTKCairoPaintIconFunc paint,
 void gui_init(dt_lib_module_t *self)
 {
   /* initialize ui widgets */
-  dt_lib_masks_t *d = (dt_lib_masks_t *)g_malloc0(sizeof(dt_lib_masks_t));
+  dt_lib_masks_t *d = g_malloc0(sizeof(dt_lib_masks_t));
   self->data = (void *)d;
 
   // initialise all masks pixbuf. This is needed for the "automatic"
