@@ -21,6 +21,7 @@ mkdir {build,AppDir}
 
 # For AppImage we have to install app in /usr subfolder of the AppDir
 export DESTDIR=../AppDir
+
 # The CLI parameters of this script will be passed verbatim to build.sh.
 # This allows you to conveniently manage the enabling/disabling of various features.
 # For example, you can easily build darktable with support for ImageMagick instead of GraphicsMagick
@@ -46,7 +47,11 @@ export VERSION=$(sh ../tools/get_git_version_string.sh)
 export DISABLE_COPYRIGHT_FILES_DEPLOYMENT=1
 
 # Instruct LDAI (LinuxDeploy AppImage plugin) to embed AppImage update information
-export LDAI_UPDATE_INFORMATION="gh-releases-zsync|darktable-org|darktable|nightly|Darktable-*-x86_64.AppImage.zsync"
+if [ "$DARKTABLE_APPIMAGE_UPDATE" == "release" ]; then
+  export LDAI_UPDATE_INFORMATION="gh-releases-zsync|darktable-org|darktable|latest|Darktable-*-x86_64.AppImage.zsync"
+elif [ "$DARKTABLE_APPIMAGE_UPDATE" != "no" ]; then
+  export LDAI_UPDATE_INFORMATION="gh-releases-zsync|darktable-org|darktable|nightly|Darktable-*-x86_64.AppImage.zsync"
+fi
 
 # '--deploy-deps-only' are needed to tell linuxdeploy where to collect dependencies
 # of modules that are loaded via dlopen (and therefore cannot be found automatically)
@@ -58,4 +63,5 @@ export LDAI_UPDATE_INFORMATION="gh-releases-zsync|darktable-org|darktable|nightl
   --deploy-deps-only ../AppDir/usr/lib/x86_64-linux-gnu/darktable/plugins/imageio/storage \
   --deploy-deps-only ../AppDir/usr/lib/x86_64-linux-gnu/darktable/plugins/lighttable \
   --deploy-deps-only ../AppDir/usr/lib/x86_64-linux-gnu/darktable/views \
+  --custom-apprun ../packaging/AppImage/AppRun \
   --output appimage
